@@ -132,4 +132,16 @@ function gradio(config, fn, target) {
     } 
 
     return io_master;
+}
+function gradio_url(config, url, target) {
+  return gradio(config, function(data) {
+    return new Promise((resolve, reject) => {
+      $.ajax({type: "POST",
+        url: url,
+        data: JSON.stringify({"data": data}),
+        success: resolve,
+        error: reject,
+      });
+    });              
+  }, target);
 }
\ No newline at end of file
